@@ -14,20 +14,16 @@ from searcHPV.general import *
 #outputDir: output directory
 #rmdup: = True: remove duplicate = False : don't remove duplicate, default = TRUE
 #multi: if fastq file is in gz format: default = True
-def alignment(fq1, fq2, humRef, virRef, outputDir, rmdup = True, gz = True):
+#index: if True, index the reference files; if False, not index the references files
+def alignment(fq1, fq2, humRef, virRef, outputDir, index, rmdup, gz):
     #make output dir
     outputDir = os.path.abspath(outputDir)
     mkdir(outputDir)
     scriptDir = f'{outputDir}/alignment'
     mkdir(scriptDir)
-
     #catenate humRef and virRef
     ref = catRef(humRef,virRef, outputDir)
 
-    #index humRef and virRef
-    indexFile = scriptDir + "/index.sh"
-    indexRef(indexFile,humRef,virRef,ref,outputDir)
-
     #generate alignment bash
 
     alignmentFile = scriptDir + "/orignal.alignment.sh"
@@ -40,23 +36,63 @@ def alignment(fq1, fq2, humRef, virRef, outputDir, rmdup = True, gz = True):
     #rmdup for alignment results
     
     bashFile = scriptDir + f"/alignment.sh"
-    if not rmdup:
-    ##generate indel alignment bash file
-        with open(bashFile,'w') as output:
-            output.write(f'''#!/bin/bash
-bash {indexFile};
-bash {alignmentFile};
-bash {indelFile};''')
+
+    if index:
+        #index humRef and virRef
+        indexFileHum = scriptDir + "/index_hum.sh"
+        indexRef(indexFileHum,humRef)
+        indexFileVir = scriptDir + "/index_vir.sh"
+        indexRef(indexFileVir,virRef)
+        indexFile = scriptDir + "/index.sh"
+        indexRef(indexFile,ref)
     else:
-        generate_mkdup_bash(indelFile,scriptDir)
+        indexFile = scriptDir + "/index.sh"
+        indexRef(indexFile,ref)
 
+    if index:
+        if rmdup:
+        ##generate mkdup alignment bash file
+            mkdupFile = scriptDir + "/mkdup.alignment.sh"
+            generate_mkdup_bash(mkdupFile,scriptDir)
 
-        with open(bashFile,'w') as output:
-            output.write(f'''#!/bin/bash
+            with open(bashFile,'w') as output:
+                output.write(f'''#!/bin/bash
+bash {indexFileHum};
+bash {indexFileVir};
+bash {indexFile};
+bash {alignmentFile};
+bash {indelFile};
+bash {mkdupFile};''')
+        else:
+            with open(bashFile,'w') as output:
+                output.write(f'''#!/bin/bash
+bash {indexFileHum};
+bash {indexFileVir};
 bash {indexFile};
 bash {alignmentFile};
 bash {indelFile};''')
 
+    else:
+        if rmdup:
+            ##generate mkdup alignment bash file
+            mkdupFile = scriptDir + "/mkdup.alignment.sh"
+            generate_mkdup_bash(mkdupFile,scriptDir)
+
+            with open(bashFile,'w') as output:
+                output.write(f'''#!/bin/bash
+bash {indexFile};
+bash {alignmentFile};
+bash {indelFile};
+bash {mkdupFile};''')
+        else:
+            with open(bashFile,'w') as output:
+                output.write(f'''#!/bin/bash
+bash {indexFile};
+bash {alignmentFile};
+bash {indelFile};''')
+
+
+
     #run scripts
     check_file(bashFile)
     os.system(f'chmod +x {bashFile}')
