@@ -22,19 +22,6 @@ def main():
     parser.add_argument('-virRef', type = str, dest = 'virRef',
                         help ='HPV reference genome: fasta file', required=True,
                         )
-    parser.add_argument('-window', type = int, default=300, dest = 'window',
-                        help ='the length of region searching for informative reads, default=300', 
-                        )
-    parser.add_argument('-clusterWindow', type = int, default=100, dest = 'clusterWindow',
-                        help ='the length of window of clustering integration sites, default=100', 
-                        )
-    parser.add_argument('-gz', action ='store_const', const = True,
-                        default = False, dest ='gz', 
-                        help ="if fastq files are in gz format")
-
-    parser.add_argument('-poly(dn)', type = int, default=20, dest = 'n',
-                        help ='poly(n), n*d(A/T/C/G), will report low confidence if contig contains poly(n), default=20', 
-                        )
     
     parser.add_argument('-output', type = str, default="./",dest = 'outputDir',
                         help ='output directory, default "./"', 
@@ -56,6 +43,31 @@ def main():
                         default = False, dest ='hpvFusion', 
                         help ="call the HPV fusion points, step4")
     
+    parser.add_argument('-window', type = int, default=300, dest = 'window',
+                        help ='the length of region searching for informative reads, default=300', 
+                        )
+    parser.add_argument('-clusterWindow', type = int, default=100, dest = 'clusterWindow',
+                        help ='the length of window of clustering integration sites, default=100', 
+                        )
+    parser.add_argument('-gz', action ='store_const', const = True,
+                        default = False, dest ='gz', 
+                        help ="if fastq files are in gz format")
+
+    parser.add_argument('-poly(dn)', type = int, default=20, dest = 'n',
+                        help ='poly(n), n*d(A/T/C/G), will report low confidence if contig contains poly(n), default=20', 
+                        )
+
+    parser.add_argument('-index', action ='store_const', const = True,
+                    default = False, dest ='index', 
+                    help ="index the original human and virus reference files, default=False")
+
+    parser.add_argument('-mkdup', action ='store_const', const = True,
+                    default = True, dest ='mkdup', 
+                    help ="mark the duplications during alignment, default=True")
+    
+    
+    
+    
 
 
 
@@ -63,7 +75,7 @@ def main():
     
   
     if args.alignment:
-        alignment(fq1 = args.fq1, fq2 = args.fq2, humRef = args.humRef, virRef = args.virRef, outputDir = args.outputDir, gz = args.gz)
+        alignment(fq1 = args.fq1, fq2 = args.fq2, humRef = args.humRef, virRef = args.virRef, index = args.index, mkdup = args.mkdup, outputDir = args.outputDir, gz = args.gz)
     elif args.genomeFusion: 
         genomeFusion(args.clusterWindow,args.outputDir,args.virRef)
     elif args.assemble: 
